@@ -111,18 +111,7 @@ def get_news():
         print(html[a],end="")
         a+=1
     print("\033[0m")
-def get_imformation(pid):
-    try:
-        url="http://code.xueersi.com/api/compilers/"+str(pid)+"?id="+str(pid)
-        headers = {'Content-Type':'application/json'}
-        a=requests.get(url=url, headers=headers)
-        null,false,list_get,string=0,0,[],''
-        p=json.loads(a.text)
-        likes=p["data"]["likes"]
-        unlikes=p["data"]["unlikes"]
-        return likes,unlikes,p["data"]["username"],p["data"]["user_id"]
-    except:
-        return -1
+
 def printf(text):
     text=str(text)
     for i in text:
@@ -130,4 +119,4 @@ def printf(text):
         time.sleep(0.1)
 def cleardevice():
     print("\033[2J")
-    print("\033[99999999999999999999999999999999A", end='')
\ No newline at end of file
+    print("\033[99999999999999999999999999999999A", end='')
